Files
project_6/cccl_upstream/docs/libcudacxx/extended_api/math/isqrt.rst

58 lines
1.1 KiB
ReStructuredText
Raw Normal View History

feat(cccl): integrate missing CCCL directories — python/, ci/, .agent/, docs/, test/ Sparse-checkout from NVIDIA/cccl main branch to complete cccl_upstream: Added: - python/cuda_cccl/ (226 files) — Python bindings for device-level algorithms Critical for muh toolchain: cuda.compute.reduce_into, scan, radix_sort, etc. Includes 204 .py files with full test coverage for all 27 algorithms - ci/ (163 files) — Build/test infrastructure build_cub.sh, test_cub.sh, build_and_test_targets.sh, matrix.yaml Directly maps to our [INFRA-CI] and [INFRA-BUILD] items - .agent/skills/ (7 files) — NVIDIA's own agent skills for CCCL cccl-style/SKILL.md, cccl-test/SKILL.md, sass-diff/SKILL.md - docs/ (491 files) — Official CCCL documentation CI references, CMake guides, Python compute docs, libcudacxx PTX docs - test/ (12 files) — Top-level integration tests (cuda_smoke, stdpar) - Root configs: .clang-format, .clang-tidy, CONTRIBUTING.md, pyproject.toml - CLAUDE.md symlink → AGENTS.md (NVIDIA's standard) cccl_upstream now mirrors full NVIDIA/cccl structure: Before: 42M (cub + thrust + libcudacxx + cudax + c + examples + benchmarks) After: 53M (+python +ci +docs +.agent +test +configs) This completes the CCCL base needed for: - [muh-bench] items: ci/util/build_and_test_targets.sh for targeted builds - [CCCL-verify] items: python/cuda_cccl/tests/ as reference implementations - [CCCL-test] items: ci/test_cub.sh, ci/test_thrust.sh - Agent workflow: .agent/skills/ for consistent style and test patterns
2026-08-07 02:34:33 +00:00
.. _libcudacxx-extended-api-math-isqrt:
``cuda::isqrt``
====================================
Defined in the ``<cuda/cmath>`` header.
.. code:: cuda
namespace cuda {
template <typename T>
[[nodiscard]] __host__ __device__ constexpr
T isqrt(T value) noexcept;
} // namespace cuda
The function computes the integer square root of the input value rounded down.
**Parameters**
- ``value``: The input value.
**Return value**
- The square root value of the input value rounded down.
**Constraints**
- ``T`` is an integer type.
**Preconditions**
- ``value`` is non-negative.
Example
-------
.. code:: cuda
#include <cuda/cmath>
#include <cuda/std/cassert>
__global__ void isqrt_kernel() {
assert(cuda::isqrt(1) == 1);
assert(cuda::isqrt(4) == 2);
assert(cuda::isqrt(42) == 6);
assert(cuda::isqrt(99) == 9);
assert(cuda::isqrt(100) == 10);
}
int main() {
isqrt_kernel<<<1, 1>>>();
cudaDeviceSynchronize();
}
`See it on Godbolt 🔗 <https://godbolt.org/z/xPcj35dq6>`__